@@ -12,7 +12,16 @@
 #'
 #' The default value of \code{sigmab} is calculated assuming the background is
 #' constant and \bold{would not} applicable when the background varies as,
-#' e.g., as observed for the early light substraction method.
+#' e.g., as observed for the early light substraction method.\cr
+#'
+#' \bold{sig0}\cr
+#'
+#' This argument allows to add an extra component of error to the final Lx/Tx error value.
+#' The input will be treated as factor that is multiplied with the already calculated
+#' LxTx and the result is add up by:
+#'
+#' \deqn{se(LxTx) = \sqrt(se(LxTx)^2 + (LxTx * sig0)^2)}
+#'
 #'
 #' \bold{background.count.distribution}\cr
 #'
@@ -55,16 +64,22 @@
 #' limits for the background integral for the Tx curve. If nothing is provided the
 #' value from \code{background.integral} is used.
 #'
-#' @param background.count.distribution \code{\link{character}} (with default): Sets
+#' @param background.count.distribution \code{\link{character}} (with default): sets
 #' the count distribution assumed for the error calculation. Possible arguments
 #' \code{poisson} or \code{non-poisson}. See details for further information
 #'
-#' @param sigmab \link{numeric} (optional): Option to set a manual value for
+#' @param sigmab \code{\link{numeric}} (optional): option to set a manual value for
 #' the overdispersion (for LnTx and TnTx), used for the Lx/Tx error
 #' calculation. The value should be provided as absolute squared count values,
 #' e.g. \code{sigmab = c(300,300)}. Note: If only one value is provided this
 #' value is taken for both (LnTx and TnTx) signals.
 #'
+#' @param sig0 \code{\link{numeric}} (with default): allow adding an extra component of error
+#' to the final Lx/Tx error value (e.g., instrumental errror, see details).
+#'
+#' @param digits \code{\link{integer}} (with default): round numbers to the specified digits. If
+#' digits is set to \code{NULL} nothing is rounded.
+#'
 #' @return Returns an S4 object of type \code{\linkS4class{RLum.Results}}.
 #'
 #' Slot \code{data} contains a \code{\link{list}} with the following structure:\cr
@@ -91,7 +106,7 @@
 #' own \code{sigmab} value or use \code{background.count.distribution = "poisson"}.
 #'
 #'
-#' @section Function version: 0.6.0
+#' @section Function version: 0.6.2
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
@@ -100,7 +115,7 @@
 #' \code{\link{Analyse_SAR.OSLdata}}, \code{\link{plot_GrowthCurve}},
 #' \code{\link{analyse_SAR.CWOSL}}
 #'
-#'  @references Duller, G., 2007. Analyst.
+#' @references Duller, G., 2007. Analyst.
 #' \url{http://www.nutech.dtu.dk/english/~/media/Andre_Universitetsenheder/Nutech/Produkter\%20og\%20services/Dosimetri/radiation_measurement_instruments/tl_osl_reader/Manuals/analyst_manual_v3_22b.ashx}\cr
 #'
 #' Galbraith, R.F., 2002. A note on the variance of a background-corrected OSL
@@ -132,7 +147,9 @@ calc_OSLLxTxRatio <- function(
   background.integral,
   background.integral.Tx = NULL,
   background.count.distribution = "non-poisson",
-  sigmab
+  sigmab = NULL,
+  sig0 = 0,
+  digits = NULL
 ){
 
   ##--------------------------------------------------------------------------##
@@ -234,8 +251,7 @@ calc_OSLLxTxRatio <- function(
 
 
   ##check sigmab
-  if (!missing(sigmab)) {
-    if (!is.null(sigmab)) {
+  if (!is.null(sigmab)) {
       if (!is(sigmab, "numeric")) {
         stop("[calc_OSLLxTxRatio()] 'sigmab' has to be of type numeric.")
       }
@@ -243,10 +259,10 @@ calc_OSLLxTxRatio <- function(
       if (length(sigmab) > 2) {
         stop("[calc_OSLLxTxRatio()] Maximum allowed vector length for 'sigmab' is 2.")
       }
-    }
   }
 
 
+
   ##--------------------------------------------------------------------------##
   ##(2) - read data and produce background subtracted values
 
@@ -313,8 +329,7 @@ calc_OSLLxTxRatio <- function(
     ## provide warning if m is < 25, as suggested by Rex Galbraith
     ## low number of degree of freedom
     if (m < 25) {
-      warning("Number of background integral channels is < 25. The calculation
-              might be not reliable!")
+      warning("[calc_OSLLxTxRatio()] Number of background channels for Lx < 25; error estimation might be not reliable!", call. = FALSE)
 
     }
 
@@ -345,10 +360,7 @@ calc_OSLLxTxRatio <- function(
     ## provide warning if m is < 25, as suggested by Rex Galbraith
     ## low number of degree of freedom
     if (m.Tx < 25) {
-      warning(
-        "Number of background integral channels for Tx is < 25. The calculation
-        might be not reliable!"
-      )
+      warning("[calc_OSLLxTxRatio()] Number of background channels for Tx < 25; error estimation might be not reliable!", call. = FALSE)
 
     }
 
@@ -358,8 +370,7 @@ calc_OSLLxTxRatio <- function(
 
 
   ##account for a manually set sigmab value
-  if (!missing(sigmab)) {
-    if (!is.null(sigmab)) {
+  if (!is.null(sigmab)) {
       if (length(sigmab) == 2) {
         sigmab.LnLx <- sigmab[1]
         sigmab.TnTx <- sigmab[2]
@@ -369,7 +380,6 @@ calc_OSLLxTxRatio <- function(
         sigmab.TnTx <- sigmab[1]
 
       }
-    }
   }
 
   ##(c)
@@ -434,8 +444,18 @@ calc_OSLLxTxRatio <- function(
   LxTx.relError <- sqrt(LnLx.relError^2 + TnTx.relError^2)
   LxTx.Error <- abs(LxTx * LxTx.relError)
 
+    ##add an extra component of error
+    LxTx.Error <- sqrt(LxTx.Error^2 + (sig0 * LxTx)^2)
+
   ##return combined values
   temp <- cbind(LnLxTnTx,LxTx,LxTx.Error)
+
+  ##apply digits if wanted
+  if(!is.null(digits)){
+    temp[1,] <- round(temp[1,], digits = digits)
+
+  }
+
   calc.parameters <- list(sigmab.LnLx = sigmab.LnLx,
                           sigmab.TnTx = sigmab.TnTx,
                           k = k)
