@@ -4,50 +4,63 @@
 #' suggested by Rex Galbraith at the UK LED in Oxford 2010.
 #'
 #' If the normal curve is added, the y-axis in the histogram will show the
-#' probability density.\cr\cr 
-#' A statistic summary, i.e. a collection of statistic measures of 
-#' centrality and dispersion (and further measures) can be added by specifying 
+#' probability density.\cr\cr
+#' A statistic summary, i.e. a collection of statistic measures of
+#' centrality and dispersion (and further measures) can be added by specifying
 #' one or more of the following keywords: \code{"n"} (number of samples),
 #' \code{"mean"} (mean De value), \code{"mean.weighted"} (error-weighted mean),
 #' \code{"median"} (median of the De values), \code{"sdrel"} (relative standard
-#' deviation in percent), \code{"sdrel.weighted"} (error-weighted relative 
+#' deviation in percent), \code{"sdrel.weighted"} (error-weighted relative
 #' standard deviation in percent), \code{"sdabs"} (absolute standard deviation),
-#' \code{"sdabs.weighted"} (error-weighted absolute standard deviation), 
+#' \code{"sdabs.weighted"} (error-weighted absolute standard deviation),
 #' \code{"serel"} (relative standard error), \code{"serel.weighted"} (
 #' error-weighted relative standard error), \code{"seabs"} (absolute standard
-#' error), \code{"seabs.weighted"} (error-weighted absolute standard error), 
+#' error), \code{"seabs.weighted"} (error-weighted absolute standard error),
 #' \code{"kurtosis"} (kurtosis) and \code{"skewness"} (skewness).
 #'
 #' @param data \code{\link{data.frame}} or \code{\linkS4class{RLum.Results}}
 #' object (required): for \code{data.frame}: two columns: De (\code{data[,1]})
-#' and De error (\code{data[,2]}) 
+#' and De error (\code{data[,2]})
+#'
 #' @param na.rm \code{\link{logical}} (with default): excludes \code{NA}
 #' values from the data set prior to any further operations.
+#'
 #' @param mtext \code{\link{character}} (optional): further sample information
 #' (\link{mtext}).
+#'
 #' @param cex.global \code{\link{numeric}} (with default): global scaling
 #' factor.
+#'
 #' @param se \code{\link{logical}} (optional): plots standard error points over
 #' the histogram, default is \code{FALSE}.
+#'
 #' @param rug \code{\link{logical}} (optional): adds rugs to the histogram,
 #' default is \code{TRUE}.
+#'
 #' @param normal_curve \code{\link{logical}} (with default): adds a normal
 #' curve to the histogram. Mean and sd are calculated from the input data. More
 #' see details section.
-#' @param summary \code{\link{character}} (optional): add statistic measures of 
-#' centrality and dispersion to the plot. Can be one or more of several 
+#'
+#' @param summary \code{\link{character}} (optional): add statistic measures of
+#' centrality and dispersion to the plot. Can be one or more of several
 #' keywords. See details for available keywords.
+#'
 #' @param summary.pos \code{\link{numeric}} or \code{\link{character}} (with
 #' default): optional position coordinates or keyword (e.g. \code{"topright"})
 #' for the statistical summary. Alternatively, the keyword \code{"sub"} may be
 #' specified to place the summary below the plot header. However, this latter
 #' option in only possible if \code{mtext} is not used. In case of coordinate
 #' specification, y-coordinate refers to the right y-axis.
+#'
 #' @param colour \code{\link{numeric}} or \link{character} (with default):
 #' optional vector of length 4 which specifies the colours of the following
 #' plot items in exactly this order: histogram bars, rug lines, normal
 #' distribution curve and standard error points\cr (e.g., \code{c("grey",
 #' "black", "red", "grey")}).
+#'
+#' @param interactive \code{\link{logical}} (with default): create an interactive
+#' histogram plot (requires the 'plotly' package)
+#'
 #' @param \dots further arguments and graphical parameters passed to
 #' \code{\link{plot}} or \code{\link{hist}}. If y-axis labels are provided,
 #' these must be specified as a vector of length 2 since the plot features two
@@ -55,6 +68,7 @@
 #' (\code{ylim}) must be provided as vector of length four, with the first two
 #' elements specifying the left axes limits and the latter two elements giving
 #' the right axis limits.
+#'
 #' @note The input data is not restricted to a special type.
 #' @section Function version: 0.4.4
 #' @author Michael Dietze, GFZ Potsdam (Germany), \cr Sebastian Kreutzer,
@@ -99,73 +113,74 @@ plot_Histogram <- function(
   summary,
   summary.pos,
   colour,
+  interactive = FALSE,
   ...
 ) {
-  
+
   # Integrity tests ---------------------------------------------------------
   ## check/adjust input data structure
   if(is(data, "RLum.Results") == FALSE &
      is(data, "data.frame") == FALSE) {
-    
+
     stop(paste("[plot_Histogram()] Input data format is neither",
                "'data.frame' nor 'RLum.Results'"))
   } else {
-    
+
     if(is(data, "RLum.Results") == TRUE) {
       data <- get_RLum(data, "data")
     }
   }
-  
+
   ## handle error-free data sets
   if(length(data) < 2) {
     data <- cbind(data, rep(NA, length(data)))
   }
-  
-  
+
+
   ## Set general parameters ---------------------------------------------------
   ## Check/set default parameters
   if(missing(cex.global) == TRUE) {
     cex.global <- 1
   }
-  
+
   if(missing(mtext) == TRUE) {
     mtext <- ""
   }
-  
+
   if(missing(se) == TRUE) {
     se = TRUE
   }
-  
+
   if(missing(rug) == TRUE) {
     rug = TRUE
   }
-  
+
   if(missing(colour) == TRUE) {
     colour = c("white", "black", "red", "black")
   }
-  
+
   if(missing(summary) == TRUE) {
     summary <- ""
   }
-  
+
   if(missing(summary.pos) == TRUE) {
     summary.pos <- "sub"
   }
-  
+
   if(missing(normal_curve) == TRUE) {
     normal_curve = FALSE
   }
-  
+
   ## read out additional arguments list
   extraArgs <- list(...)
-  
+
   ## define fun
   if("fun" %in% names(extraArgs)) {
     fun <- extraArgs$fun
   } else {
     fun <- FALSE
   }
-  
+
   ## optionally, count and exclude NA values and print result
   if(na.rm == TRUE) {
     n.NA <- sum(is.na(data[,1]))
@@ -176,39 +191,39 @@ plot_Histogram <- function(
     }
     data <- data[!is.na(data[,1]),]
   }
-  
+
   if("main" %in% names(extraArgs)) {
     main.plot <- extraArgs$main
   } else {
     main.plot <- "Histogram"
   }
-  
+
   if("xlab" %in% names(extraArgs)) {
     xlab.plot <- extraArgs$xlab
   } else {
-    xlab.plot <- expression(paste(D[e], " (Gy)"))
+    xlab.plot <- expression(paste(D[e], " [Gy]"))
   }
-  
+
   if("ylab" %in% names(extraArgs)) {
     ylab.plot <- extraArgs$ylab
   } else {
     ylab.plot <- c("Frequency",
                    "Standard error")
   }
-  
+
   if("breaks" %in% names(extraArgs)) {
     breaks.plot <- extraArgs$breaks
   } else {
     breaks.plot <- hist(x = data[,1],
                         plot = FALSE)$breaks
   }
-  
+
   if("xlim" %in% names(extraArgs)) {
     xlim.plot <- extraArgs$xlim
   } else {
     xlim.plot <- range(breaks.plot)
   }
-  
+
   if("ylim" %in% names(extraArgs)) {
     ylim.plot <- extraArgs$ylim
   } else {
@@ -226,7 +241,7 @@ plot_Histogram <- function(
     range.error[2] <- ifelse(is.infinite(range.error[2]), 0, range.error[2])
     ylim.plot <- c(left.ylim, range.error)
   }
-  
+
   if("pch" %in% names(extraArgs)) {
     pch.plot <- extraArgs$pch
   } else {
@@ -235,7 +250,7 @@ plot_Histogram <- function(
   ## Set plot area format
   par(mar = c(4.5, 4.5, 4.5, 4.5),
       cex = cex.global)
-  
+
   ## Plot histogram -----------------------------------------------------------
   HIST <- hist(data[,1],
                main = "",
@@ -247,20 +262,20 @@ plot_Histogram <- function(
                freq = !normal_curve,
                col = colour[1]
   )
-  
+
   ## add title
   title(line = 2,
         main = main.plot)
-  
+
   ## Optionally, add rug ------------------------------------------------------
   if(rug == TRUE) {rug(data[,1], col = colour[2])}
-  
+
   ## Optionally, add a normal curve based on the data -------------------------
   if(normal_curve == TRUE){
     ## cheat the R check routine, tztztz how neat
     x <- NULL
     rm(x)
-    
+
     ## add normal distribution curve
     curve(dnorm(x,
                 mean = mean(na.exclude(data[,1])),
@@ -269,10 +284,10 @@ plot_Histogram <- function(
           add = TRUE,
           lwd = 1.2 * cex.global)
   }
-  
+
   ## calculate and paste statistical summary
   data.stats <- list(data = data)
-  
+
   ## calculate and paste statistical summary
   De.stats <- matrix(nrow = length(data), ncol = 18)
   colnames(De.stats) <- c("n",
@@ -293,7 +308,7 @@ plot_Histogram <- function(
                           "sd.rel.weighted",
                           "se.abs.weighted",
                           "se.rel.weighted")
-  
+
   for(i in 1:length(data)) {
     statistics <- calc_Statistics(data)
     De.stats[i,1] <- statistics$weighted$n
@@ -313,26 +328,26 @@ plot_Histogram <- function(
     De.stats[i,16] <- statistics$weighted$sd.rel
     De.stats[i,17] <- statistics$weighted$se.abs
     De.stats[i,18] <- statistics$weighted$se.rel
-    
+
     ##kdemax - here a little doubled as it appears below again
     De.density <-density(x = data[,1],
                          kernel = "gaussian",
                          from = xlim.plot[1],
                          to = xlim.plot[2])
-    
+
     De.stats[i,6] <- De.density$x[which.max(De.density$y)]
   }
-  
+
   label.text = list(NA)
-  
+
   if(summary.pos[1] != "sub") {
     n.rows <- length(summary)
-    
+
     for(i in 1:length(data)) {
       stops <- paste(rep("\n", (i - 1) * n.rows), collapse = "")
-      
+
       summary.text <- character(0)
-      
+
       for(j in 1:length(summary)) {
         summary.text <- c(summary.text,
                           paste(
@@ -435,9 +450,9 @@ plot_Histogram <- function(
                                    ""),
                             sep = ""))
       }
-      
+
       summary.text <- paste(summary.text, collapse = "")
-      
+
       label.text[[length(label.text) + 1]] <- paste(stops,
                                                     summary.text,
                                                     stops,
@@ -445,9 +460,9 @@ plot_Histogram <- function(
     }
   } else {
     for(i in 1:length(data)) {
-      
+
       summary.text <- character(0)
-      
+
       for(j in 1:length(summary)) {
         summary.text <- c(summary.text,
                           ifelse("n" %in% summary[j] == TRUE,
@@ -548,15 +563,15 @@ plot_Histogram <- function(
                                  "")
         )
       }
-      
+
       summary.text <- paste(summary.text, collapse = "")
-      
+
       label.text[[length(label.text) + 1]]  <- paste(
         "  ",
         summary.text,
         sep = "")
     }
-    
+
     ## remove outer vertical lines from string
     for(i in 2:length(label.text)) {
       label.text[[i]] <- substr(x = label.text[[i]],
@@ -564,10 +579,10 @@ plot_Histogram <- function(
                                 stop = nchar(label.text[[i]]) - 3)
     }
   }
-  
+
   ## remove dummy list element
   label.text[[1]] <- NULL
-  
+
   ## convert keywords into summary placement coordinates
   if(missing(summary.pos) == TRUE) {
     summary.pos <- c(xlim.plot[1], ylim.plot[2])
@@ -603,7 +618,7 @@ plot_Histogram <- function(
     summary.pos <- c(xlim.plot[2], ylim.plot[1])
     summary.adj <- c(1, 0)
   }
-  
+
   ## add summary content
   for(i in 1:length(data.stats)) {
     if(summary.pos[1] != "sub") {
@@ -623,16 +638,16 @@ plot_Histogram <- function(
       }
     }
   }
-  
+
   ## Optionally, add standard error plot --------------------------------------
   if(sum(is.na(data[,2])) == length(data[,2])) {
     se <- FALSE
   }
-  
+
   if(se == TRUE) {
     par(new = TRUE)
     plot.data <- data[!is.na(data[,2]),]
-    
+
     plot(x = plot.data[,1],
          y = plot.data[,2],
          xlim = xlim.plot,
@@ -653,17 +668,97 @@ plot_Histogram <- function(
           side = 4,
           line = 3,
           cex = cex.global)
-    
+
     #    par(new = FALSE)
   }
-  
+
   ## Optionally add user-defined mtext
   mtext(side = 3,
         line = 0.5,
         text = mtext,
         cex = 0.8 * cex.global)
-  
+
   ## FUN by R Luminescence Team
-  if(fun==TRUE){sTeve()}
-  
+  if(fun & !interactive)
+    sTeve()
+
+  ## Optionally: Interactive Plot ----------------------------------------------
+  if (interactive) {
+
+    if (!requireNamespace("plotly", quietly = TRUE))
+      stop("The interactive histogram requires the 'plotly' package. To install",
+           " this package run 'install.packages('plotly')' in your R console.",
+           call. = FALSE)
+
+    ## tidy data ----
+    data <- as.data.frame(data)
+    colnames(data) <- c("x", "y")
+    x <- y <- NULL # suffice CRAN check for no visible binding
+    if (length(grep("paste", as.character(xlab.plot))) > 0)
+      xlab.plot <- "Equivalent dose [Gy]"
+
+
+    ## create plots ----
+
+    # histogram
+    hist <- plotly::plot_ly(data = data, x = x,
+                            type = "histogram",
+                            showlegend = FALSE,
+                            name = "Bin", opacity = 0.75,
+                            marker = list(color = "428BCA",
+                                          line = list(width = 1.0,
+                                                      color = "white")),
+                            histnorm = ifelse(normal_curve, "probability density", ""),
+                            yaxis = "y"
+    )
+
+    # normal curve ----
+    if (normal_curve) {
+
+      density.curve <- density(data$x)
+      normal.curve <- data.frame(x = density.curve$x, y = density.curve$y)
+
+      hist <- plotly::add_trace(hist, data = normal.curve, x = x, y = y,
+                                type = "scatter", mode = "lines",
+                                marker = list(color = "red"),
+                                name = "Normal curve",
+                                yaxis = "y")
+
+    }
+
+    # scatter plot of individual errors
+    if (se) {
+      yaxis2 <- list(overlaying = "y", side = "right",
+                     showgrid = FALSE, title = ylab.plot[2],
+                     ticks = "", showline = FALSE)
+
+      se.text <- paste0("Measured value:</br>",
+                        data$x, " &plusmn; ", data$y,"</br>")
+
+      hist <- plotly::add_trace(hist, data = data, x = x, y = y,
+                                type = "scatter", mode = "markers",
+                                name = "Error", hoverinfo = "text",
+                                text = se.text,
+                                marker = list(color = "black"),
+                                yaxis = "y2")
+
+      hist <- plotly::layout(yaxis2 = yaxis2)
+    }
+
+    # set layout ----
+    hist <- plotly::layout(hist, hovermode = "closest",
+                           title = paste("<b>", main.plot, "</b>"),
+                           margin = list(r = 90),
+                           xaxis = list(title = xlab.plot,
+                                        ticks = ""),
+                           yaxis = list(title = ylab.plot[1],
+                                        ticks = "",
+                                        showline = FALSE,
+                                        showgrid = FALSE)
+    )
+
+    ## show plot ----
+    print(hist)
+  }
+
 }
